<?php
/**
 * A filter for validating the refill request
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class RefillRequestValidatorFilter extends BaseFrameworkSystem implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public final static function createRefillRequestValidatorFilter () {
		// Get a new instance
		$filterInstance = new RefillRequestValidatorFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	0% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Are all required request fields set?
		if ((!$requestInstance->isRequestElementSet('type')) || (!$requestInstance->isRequestElementSet('amount'))) {
			// Something important is missing
			$requestInstance->requestIsValid(false);

			// Add a message to the response
			$responseInstance->addFatalMessage('refill_page_required_fields_missing');

			// Abort here
			return false;
		} // END - if
		die("OK!");
	}
}

// [EOF]
?>
