<?php
/**
 * An interface for managing applications. This can be a lot. E.g.:
 *
 * - Un-/locking applications
 * - Creating selectors for the selector-mode
 * - Usage statistics
 * - And many more...
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface ManageableApplication extends FrameworkInterface {
	/**
	 * Getter for application's version number
	 *
	 * @return	$appVersion	The application's version number
	 */
	function getAppVersion ();
	/**
	 * Setter for application's version number
	 *
	 * @param		$appVersion	The application's version number
	 * @return	void
	 */
	function setAppVersion ($appVersion);

	/**
	 * Getter for application's human-readable name
	 *
	 * @return	$appName	The application's name readable for humans
	 */
	function getAppName ();

	/**
	 * Setter for application's human-readable name
	 *
	 * @param		$appName	The application's name readable for humans
	 * @return	void
	 */
	function setAppName ($appName);

	/**
	 * Getter for application's short uni*-like name
	 *
	 * @return	$shortName	The application's name readable for humans
	 */
	function getAppShortName ();

	/**
	 * Setter for application's short uni*-like name
	 *
	 * @param		$shortName	The application's name readable for humans
	 * @return	void
	 */
	function setAppShortName ($shortName);

	/**
	 * Getter for master template name
	 *
	 * @return	$masterTemplate		Name of the master template
	 */
	function getMasterTemplate ();

	/**
	 * Launches the application
	 *
	 * @return	void
	 */
	function entryPoint ();

	/**
	 * Handle the indexed array of fatal messages and puts them out in an
	 * acceptable fasion
	 *
	 * @param	$messageList	An array of fatal messages
	 * @return	void
	 */
	function handleFatalMessages (array $messageList);
}

// [EOF]
?>
